=====================
Differential Geometry
=====================

.. module:: sympy.diffgeom

Introduction
------------

Base Class Reference
--------------------
.. autoclass:: Manifold
   :members:

.. autoclass:: Patch
   :members:

.. autoclass:: CoordSystem
   :members:

.. autoclass:: CoordinateSymbol
   :members:

.. autoclass:: Point
   :members:

.. autoclass:: BaseScalarField
   :members:

.. autoclass:: BaseVectorField
   :members:

.. autoclass:: Commutator
   :members:

.. autoclass:: Differential
   :members:

.. autoclass:: TensorProduct
   :members:

.. autoclass:: WedgeProduct
   :members:

.. autoclass:: LieDerivative
   :members:

.. autoclass:: BaseCovarDerivativeOp
   :members:

.. autoclass:: CovarDerivativeOp
   :members:

.. autofunction:: intcurve_series

.. autofunction:: intcurve_diffequ

.. autofunction:: vectors_in_basis

.. autofunction:: twoform_to_matrix

.. autofunction:: metric_to_Christoffel_1st

.. autofunction:: metric_to_Christoffel_2nd

.. autofunction:: metric_to_Riemann_components

.. autofunction:: metric_to_Ricci_components
